<?php

namespace Drupal\jsonapi_image_style_metadata\Plugin\Field\FieldType;

use Drupal\Core\Field\MapFieldItemList;
use Drupal\Core\TypedData\ComputedItemListTrait;
use Drupal\file\Entity\File;
use Drupal\image\Entity\ImageStyle;

/**
 * Represents the computed image style metadata for a file entity.
 */
class ImageStyleMetadataNormalizedFieldItemList extends MapFieldItemList {

  use ComputedItemListTrait;

  /**
   * {@inheritdoc}
   */
  protected function computeValue() {
    $file = $this->getEntity();
    $fid = $file->id();
    $uri = ($file instanceof File && substr($file->getMimeType(), 0, 5) === 'image') ? $file->getFileUri() : FALSE;
    if ($uri) {
      $query = \Drupal::entityQuery('image_style_metadata')
        ->accessCheck(TRUE)
        ->condition('fid', $fid);
      $ids = $query->execute();
      $metadata_entities = \Drupal::entityTypeManager()->getStorage('image_style_metadata')->loadMultiple($ids);
      $styles = [];
      foreach ($metadata_entities as $metadata_entity) {
        $style = ImageStyle::load($metadata_entity->style->value);
        $style_uri = $style->buildUrl($uri);
        $styles[$metadata_entity->style->value] = [
          'uri' => $style_uri,
          'width' => $metadata_entity->width->value,
          'height' => $metadata_entity->height->value,
        ];
      }

      $clone = clone $file;
      \Drupal::moduleHandler()->alter('jsonapi_image_style_metadata', $styles, $metadata_entities, $clone);

      $this->list[] = $this->createItem(0, $styles);
    }
  }

}
