<?php

namespace Drupal\image_style_metadata\Drush\Commands;

use Drupal\Core\Batch\BatchBuilder;
use Drush\Attributes as CLI;
use Drush\Commands\DrushCommands;

final class ImageStyleMetadataCommands extends DrushCommands {

  /**
   * Generates metadata for all existing derivative images.
   */
  #[CLI\Command(name: 'image_style_metadata:generate-metadata', aliases: ['ism:gm'])]
  #[CLI\Option(name: 'method', description: 'Which method to use (Valid values: direct, queue).')]
  #[CLI\Option(name: 'force-recreate', description: 'Force recreate existing entities.')]
  public function generateMetadata(array $options = ['method' => 'direct', 'force-recreate' => TRUE]) {
    $force_recreate = (bool) $options['force-recreate'];
    $method = $options['method'] ?? 'direct';
    if ($method && !in_array($method, ['direct', 'queue'])) {
      $this->writeln(dt('Invalid method. Valid values: direct, queue.'));
      return;
    }

    $batch_builder = (new BatchBuilder());
    $batch_builder->setTitle(t('Generating Image Style Metadata entities'))
      ->setFinishCallback('image_style_metadata_batch_finished')
      ->setInitMessage(t('Batch is starting'))
      ->setProgressMessage(t('Processed @current out of @total.'))
      ->setErrorMessage(t('Batch has encountered an error'));
    $batch_builder->addOperation('image_style_metadata_batch_operation', [$method, $force_recreate]);
    batch_set($batch_builder->toArray());
    drush_backend_batch_process();
  }

}
