<?php

namespace Drupal\image_style_metadata\Entity;

use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityChangedTrait;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;

/**
 * Defines the Image Style Metadata entity class.
 *
 * @ContentEntityType(
 *   id = "image_style_metadata",
 *   label = @Translation("Image style metadata"),
 *   label_collection = @Translation("Image style metadata"),
 *   label_singular = @Translation("Image style metadata"),
 *   label_plural = @Translation("Image style metadata"),
 *   label_count = @PluralTranslation(
 *     singular = "@count image style metadata",
 *     plural = "@count image style metadata",
 *   ),
 *   handlers = {
 *     "views_data" = "Drupal\views\EntityViewsData",
 *   "access" = "Drupal\image_style_metadata\AccessControlHandler",
 *   },
 *   base_table = "image_style_metadata",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "id",
 *     "uuid" = "uuid",
 *   },
 * )
 */
final class ImageStyleMetadata extends ContentEntityBase {

  use EntityChangedTrait;

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type): array {

    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['fid'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('File ID'))
      ->setDescription(t('The file entity.'))
      ->setSetting('target_type', 'file');

    $fields['style'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Style'))
      ->setDescription(t('The image style.'))
      ->setSetting('max_length', 255);

    $fields['width'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Width'))
      ->setDescription(t('The width of the image.'))
      ->setRequired(TRUE)
      ->setSetting('unsigned', TRUE);

    $fields['height'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Height'))
      ->setDescription(t('The height of the image.'))
      ->setRequired(TRUE)
      ->setSetting('unsigned', TRUE);

    $fields['changed'] = BaseFieldDefinition::create('changed')
      ->setLabel(t('Changed'))
      ->setDescription(t('The time that the entity was last edited.'));

    return $fields;
  }

}
