<?php

namespace Drupal\image_style_metadata\Form;

use Drupal\Core\Batch\BatchBuilder;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

class ImageStyleMetadataBatchForm extends FormBase {

  public function getFormId() {
    return 'image_style_metadata_batch_form';
  }

  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['description'] = [
      '#type' => 'markup',
      '#prefix' => '<div>',
      '#suffix' => '</div>',
      '#markup' => $this->t('Recreate Image Style Metadata entities for all the existing derivative images.'),
    ];

    $form['method'] = [
      '#type' => 'select',
      '#title' => $this->t('Method'),
      '#options' => [
        'direct' => $this->t('Direct'),
        'queue' => $this->t('Queue'),
      ],
      '#default_value' => 'direct',
      '#description' => $this->t('Choose the method to use.'),
    ];

    $form['force'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Force recreate existing entities'),
      '#default_value' => TRUE,
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => 'Go',
    ];

    return $form;
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    $method = $form_state->getValue('method');
    $force = $form_state->getValue('force');

    $batch_builder = (new BatchBuilder());
    $batch_builder->setTitle(t('Generating Image Style Metadata entities'))
      ->setFinishCallback('image_style_metadata_batch_finished')
      ->setInitMessage(t('Batch is starting'))
      ->setProgressMessage(t('Processed @current out of @total.'))
      ->setErrorMessage(t('Batch has encountered an error'));
    $batch_builder->addOperation('image_style_metadata_batch_operation', [$method, $force]);
    batch_set($batch_builder->toArray());
  }

}
