<?php

namespace Drupal\image_style_metadata\Form;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure Image Style Metadata settings for this site.
 */
final class ImageStyleMetadataSettingsForm extends ConfigFormBase {

  // @TODO schema yml

  public function getFormId(): string {
    return 'image_style_metadata_settings_form';
  }

  protected function getEditableConfigNames(): array {
    return ['image_style_metadata.settings'];
  }

  public function buildForm(array $form, FormStateInterface $form_state): array {
    $saved_config = $this->config('image_style_metadata.settings')->get('default_method');

    $options = [
      'direct' => $this->t('Direct'),
      'queue' => $this->t('Queue'),
    ];

    $form['default_method'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Default method'),
      '#tree' => TRUE,
    ];
    // Get all the image styles.
    $styles = $this->entityTypeManager->getStorage('image_style')->loadMultiple();
    // Iterate over each image style and create a dropdown with the $options for each one.
    foreach ($styles as $style) {
      $form['default_method'][$style->id()] = [
        '#type' => 'select',
        '#title' => $style->label(),
        '#options' => $options,
        '#default_value' => $saved_config[$style->id()] ?? 'queue',
      ];
    }

    return parent::buildForm($form, $form_state);
  }

  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('image_style_metadata.settings')
      ->set('default_method', $form_state->getValue('default_method'))
      ->save();
    parent::submitForm($form, $form_state);
  }

  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->entityTypeManager = $container->get('entity_type.manager');
    return $instance;
  }

  protected EntityTypeManagerInterface $entityTypeManager;

}
