<?php

namespace Drupal\image_style_metadata;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Image\ImageFactory;
use Drupal\Core\Queue\QueueFactory;
use Drupal\Core\StreamWrapper\StreamWrapperManagerInterface;

/**
 * @todo Add class description.
 */
final class ImageStyleMetadataService {

  public function createEntity($fid, $style, $derivative_uri, $force_recreate = TRUE) {
    // Load the image style metadata entity, if one is found.
    $properties = [
      'fid' => $fid,
      'style' => $style,
    ];
    $storage = $this->entityTypeManager->getStorage('image_style_metadata');
    $image_style_metadata = $storage->loadByProperties($properties);
    if ($image_style_metadata) {
      if (!$force_recreate) {
        return;
      }
      $image_style_metadata = reset($image_style_metadata);
    }
    else {
      $image_style_metadata = $storage->create([
        'fid' => $fid,
        'style' => $style,
      ]);
    }
    $derivative_image = $this->imageFactory->get($derivative_uri);
    $width = $derivative_image->getWidth();
    $height = $derivative_image->getHeight();
    $image_style_metadata->set('width', $width);
    $image_style_metadata->set('height', $height);

    $this->moduleHandler->alter('image_style_metadata', $image_style_metadata, $derivative_image);

    $image_style_metadata->save();
  }

  public function createEntityDirectly($fid, $style_name, $derivative_uri, $force_recreate) {
    // Resolve the stream wrapper for the URI.
    $stream_wrapper = $this->streamWrapperManager->getViaUri($derivative_uri);

    // Attempt to open the file directly using fopen, which works with remote filesystems.
    if ($stream_wrapper && ($handle = @fopen($derivative_uri, 'r'))) {
      $this->createEntity($fid, $style_name, $derivative_uri, $force_recreate);
      fclose($handle);
    }
  }

  public function createQueueItem($fid, $style_name, $derivative_uri, $force_recreate) {
    $queue = $this->queueFactory->get('image_style_metadata_generate');
    $queue->createItem([
      'fid' => $fid,
      'style' => $style_name,
      'derivative_uri' => $derivative_uri,
      'force_recreate' => $force_recreate,
    ]);
  }

  public function __construct(
    private readonly EntityTypeManagerInterface $entityTypeManager,
    private readonly StreamWrapperManagerInterface $streamWrapperManager,
    private readonly ImageFactory $imageFactory,
    private readonly QueueFactory $queueFactory,
    private readonly ModuleHandlerInterface $moduleHandler,
  ) {}

}
