<?php

namespace Drupal\image_style_metadata\Plugin\QueueWorker;

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines 'image_style_metadata_cleanup' queue worker.
 *
 * @QueueWorker(
 *   id = "image_style_metadata_cleanup",
 *   title = @Translation("Clean up image style metadata after file deletion"),
 *   cron = {"time" = 60},
 * )
 */
class CleanUp extends QueueWorkerBase {

  public function processItem($data) {
    $fid = $data['fid'];
    $properties = ['fid' => $fid];
    $image_style_metadata = $this->storage->loadByProperties($properties);
    if ($image_style_metadata) {
      $this->storage->delete($image_style_metadata);
    }
  }

  public function __construct(array $configuration, $plugin_id, array $plugin_definition, EntityTypeManagerInterface $entity_type_manager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->storage = $entity_type_manager->getStorage('image_style_metadata');
  }

  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager'),
    );
  }

  private EntityStorageInterface $storage;

}
