<?php

namespace Drupal\image_style_metadata\Plugin\QueueWorker;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\Core\StreamWrapper\StreamWrapperManagerInterface;
use Drupal\image_style_metadata\ImageStyleMetadataService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines 'image_style_metadata_generate' queue worker.
 *
 * @QueueWorker(
 *   id = "image_style_metadata_generate",
 *   title = @Translation("Generate Image Style Metadata entity"),
 *   cron = {"time" = 60},
 * )
 */
final class Generate extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  public function processItem($data): void {
    $fid = $data['fid'];
    $style = $data['style'];
    $derivative_uri = $data['derivative_uri'];
    $force_recreate = $data['force_recreate'];
    $stream_wrapper = $this->streamWrapperManager->getViaUri($derivative_uri);
    if ($stream_wrapper && ($handle = @fopen($derivative_uri, 'r'))) {
      $this->service->createEntity($fid, $style, $derivative_uri, $force_recreate);
      fclose($handle);
    }
  }

  public function __construct(array $configuration, $plugin_id, array $plugin_definition, StreamWrapperManagerInterface $stream_wrapper_manager, ImageStyleMetadataService $service) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->streamWrapperManager = $stream_wrapper_manager;
    $this->service = $service;
  }

  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('stream_wrapper_manager'),
      $container->get('image_style_metadata.service')
    );
  }

  private StreamWrapperManagerInterface $streamWrapperManager;

  private ImageStyleMetadataService $service;

}
